<?xml version="1.0" encoding="UTF-8" ?>
<!-- showme.xsl
 | DITA showme javascript support - this is the shell XSL for integrating the code modules
 | DITA tutorial and sample gallery launching support - adds javascript to support links to galleries
 | Updated with /swf internal changes, moved camera gif to com.ibm.help.doc  BK 9/05/06
-->

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:saxon="http://icl.com/saxon"
                xmlns:xt="http://www.jclark.com/xt"
                extension-element-prefixes="saxon xt">

<!-- stylesheet imports -->
<!-- the main dita to xhtml converter -->
<xsl:import href="idit2htm.xsl"/>

<!--expected format for showme links:
href: viewlet-name
navtitle/linktext: show me
format: viewlet
type: showme
-->


<!-- Output XHTML with XML syntax, use UFT-8 encoding="UTF-8", transitional XHTML.
     Prevent indenting to conserve space on output. -->
<!-- <xsl:output method="xml" -->
<xsl:output method="saxon:xhtml"
            encoding="UTF-8"
            indent="no"
            doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
            doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
/>

<!--overriding relinfo-links to ignore showme links-->
<xsl:template name="relinfo-links">
     <!--other info- - not currently sorting by role, since already mixing any number of types in here-->
     <!--if there are links not covered by any of the other routines - ie, not in a linklist, not a child or descendant, not a concept/task/reference, not ancestor/next/previous, not prerequisite - create a section for them and create the links-->
     <xsl:if test="descendant::*
[contains(@class, ' topic/link ')]
[not(ancestor::*[contains(@class,' topic/linklist ')])]
          [not(@role='child' or @role='descendant' or @role='ancestor' or @role='parent' or @role='next' or @role='previous' or @type='concept' or @type='task' or @type='reference' or @type='showme')]
          [not(@importance='required' and (not(@role) or @role='sibling' or @role='friend' or @role='cousin'))]">
          <div>
          <strong>
             <xsl:call-template name="getString">
                  <xsl:with-param name="stringName" select="'Related information'"/>
               </xsl:call-template>
          </strong>
       <!--once section is created, create the links, using the same rules as bove plus a uniqueness check-->
       <xsl:for-each select="descendant::*
          [not(ancestor::*[contains(@class,' topic/linklist ')])]
          [generate-id(.)=generate-id(key('link',concat(ancestor::*[contains(@class, ' topic/related-links ')]/parent::*[contains(@class, ' topic/topic ')]/@id, ' ', @href,@type,@role,@platform,@audience,@importance,@outputclass,@keyref,@scope,@format,@otherrole,@product,@otherprops,@rev,@class,child::*))[1])]
[contains(@class, ' topic/link ')]
          [not(@role='child' or @role='descendant' or @role='ancestor' or @role='parent' or @role='next' or @role='previous' or @type='concept' or @type='task' or @type='reference' or @type='showme')]
          [not(@importance='required' and (not(@role) or @role='sibling' or @role='friend' or @role='cousin'))]">
          <xsl:apply-templates select="."/>
       </xsl:for-each>

          </div>
     </xsl:if>
</xsl:template>

  <!-- Modified override for  shortdesc template to include code to
  open showme viewlet on same page.  dwh :: 06.Mar.06 -->
  <xsl:template match="*[contains(@class,' topic/shortdesc ')]" mode="outofline">
    <div>
      <xsl:for-each select="following-sibling::*[contains(@class,' topic/related-links ')]/descendant::*[contains(@class,' topic/link ')][@format='viewlet'][@type='showme']">
      <div class="showme">
      <div class="collapseheadshowme">
        <a href="javascript:void(0)"
           class="collapsehead"
           onclick="collapse(this)">
           <!-- <img src="../../com.ibm.help.doc/images/camera2.gif" border="none" align="middle" alt=""></img> -->
           <xsl:value-of select="." /></a>
      </div>
      <div class="collapsecontent">
        <div class="section">
          <xsl:element name="object">
            <xsl:attribute name="id">11</xsl:attribute>
            <xsl:attribute name="codebase">http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab</xsl:attribute>
            <xsl:attribute name="type">application/x-shockwave-flash</xsl:attribute>
            <xsl:attribute name="classid">clsid:D27CDB6E-AE6D-11cf-96B8-444553540000</xsl:attribute>
            <xsl:attribute name="data">../swf/<xsl:value-of select="@href" />.swf</xsl:attribute>
            <xsl:attribute name="width">800</xsl:attribute>
            <xsl:attribute name="height">600</xsl:attribute>
            <xsl:element name="param">
              <xsl:attribute name="name">movie</xsl:attribute>
              <xsl:attribute name="value">../swf/<xsl:value-of select="@href" />.swf</xsl:attribute>
            </xsl:element>
            <xsl:element name="param">
              <xsl:attribute name="name">pluginspace</xsl:attribute>
              <xsl:attribute name="value">http://www.macromedia.com/go/getflashplayer</xsl:attribute>
            </xsl:element>
            <xsl:element name="embed">
              <xsl:attribute name="name">11</xsl:attribute>
              <xsl:attribute name="width">800</xsl:attribute>
              <xsl:attribute name="height">600</xsl:attribute>
              <xsl:attribute name="type">application/x-shockwave-flash</xsl:attribute>
              <xsl:attribute name="pluginspace">http://www.macromedia.com/go/getflashplayer</xsl:attribute>
              <xsl:attribute name="src">../swf/<xsl:value-of select="@href" />.swf</xsl:attribute>
            </xsl:element>
          </xsl:element>
        </div>
      </div>
      </div>
       </xsl:for-each>
      <xsl:call-template name="commonattributes"/>
      <xsl:apply-templates/>
    </div>
  </xsl:template>


<!--overriding gen-user-scripts stub to call showme javascript-->
<xsl:template name="gen-user-scripts">
  <!-- Commented out so that no Javascript templates are called.
  dwh :: 04.Apr
  <xsl:call-template name="showme-script"/>
  <xsl:call-template name="gallery-script"/>
  <xsl:call-template name="tutorial-javascript" />
  -->
</xsl:template>

<!-- No longer called. dwh :: 04.Apr
<xsl:template name="showme-script">
<script language="JavaScript">
    function popup_window( url, id, width, height )
    {
      popup = window.open( url, id, 'toolbar=no,scrollbars=no,location=no,statusbar=no,menubar=no,resizable=no,width=' + width + ',height=' + height + ',left=,top=' );
      popup.focus();
    }
</script>
</xsl:template>
-->

<!-- No longer called. dwh :: 04.Apr
<xsl:template name="gallery-script">
<script language="JavaScript" src="help/liveHelp.js"></script>

</xsl:template>
-->

  <!-- Tutorial Javascript -->
  <!-- No longer called. dwh :: 04.Apr
  <xsl:template name="tutorial-javascript">
    <script type="text/javascript">
    <xsl:comment>
      // define JavaScript within here; use CDATA sections as appropriate
      <![CDATA[function tutorialAction(pluginID, className, arg) {
        var ref = "/TutorialGallery/livehelp/?pluginID=" + pluginID + "&class=" + className + "&arg=" + arg;
        self.location.replace(ref);
      }

      function linkHelp(helpitem) {
        var ref = "/TutorialGallery/livehelp/?pluginID=com.ibm.tutorialgallery&class=com.ibm.tutorialgallery.OpenHelpAction&arg=" + helpitem;
        self.location.replace(ref);
      }

      function linkSample(sample) {
        var ref = "/TutorialGallery/livehelp/?pluginID=com.ibm.samplegallery&class=com.ibm.samplegallery.SampleGalleryAction&arg=" + sample;
        self.location.replace(ref);
      }

      function collapse(loc){

        //Navigate to the content division using DOM, then change its style
        var foc=loc.parentNode.parentNode.childNodes[1];
        foc.style.display=foc.style.display=='block'?'none':'block';

        //Find the header anchor by navigating the DOM tree, then change its class attribute to use a different style
        var headA = loc.parentNode.firstChild;
        headA.className=headA.className=='collapsehead'?'collapseheadopen':'collapsehead';

      }]]>
    //</xsl:comment>
    </script>
  </xsl:template>
  -->


<!-- overrides for dynamic image resizing, added 11-14-2005 -->
<!-- these are based on IDWB 3.8.3 templates                -->
<!-- additions or changes noted by ******                   -->
<!-- updated 06/14/2006 jta                                 -->

<!-- <xsl:variable name="jscriptresize">javascript:resizeimage(this);</xsl:variable> jta removed 06/14/2006 ****** -->
<!-- <xsl:variable name="jscriptreload">location.reload();</xsl:variable> jta removed 06/14/2006 ****** -->
<xsl:variable name="jscriptonload">javascript:resizeAtPageLoad();</xsl:variable> <!-- jta added 06/14/2006 ****** -->
<xsl:variable name="jscriptresize">javascript:resizeAllImages();</xsl:variable>  <!-- jta added 06/14/2006 ****** -->

<!-- jta removing 06/14/2006; just call resizer.js
<xsl:template name="topic-image">
  <!- - now invoke the actual content and its alt text - ->
  <xsl:element name="img">
    <xsl:call-template name="commonattributes"/>
    <xsl:call-template name="setid"/>
    <xsl:apply-templates select="@href|@height|@width|@longdescref"/>
    <xsl:choose>
      <xsl:when test="*[contains(@class,' topic/alt')]">
        <xsl:attribute name="alt"><xsl:value-of select="normalize-space(*[contains(@class,' topic/alt ')])"/></xsl:attribute>
      </xsl:when>
      <xsl:when test="@alt">
        <xsl:attribute name="alt"><xsl:value-of select="@alt"/></xsl:attribute>
      </xsl:when>
    </xsl:choose>
    <xsl:attribute name="onload"><xsl:value-of select="$jscriptresize"/></xsl:attribute> <!- - ****** - ->
    <xsl:attribute name="name"><xsl:value-of select="@href"/></xsl:attribute>            <!- - ****** - ->
  </xsl:element>
</xsl:template>
-->

<xsl:template name="chapter-setup">
<html>

<!-- test for a bidi language code on 1st 'topic' tag
     also need to look at 1st topic following dita -->
 <!--<xsl:variable name="childlangUpper">
  <xsl:choose>
   <xsl:when test="descendant-or-self::*/@xml:lang">
     <xsl:value-of select="descendant-or-self::*/@xml:lang"/>
   </xsl:when>
   <xsl:otherwise>en-us</xsl:otherwise>
  </xsl:choose>
 </xsl:variable>
 <xsl:variable name="childlang">
  <xsl:call-template name="convert-to-lower">
   <xsl:with-param name="inputval" select="$childlangUpper"/>
  </xsl:call-template>
 </xsl:variable>-->
 <xsl:variable name="childlang">
     <xsl:choose>
         <xsl:when test="self::dita">
             <xsl:for-each select="*[1]"><xsl:call-template name="getLowerCaseLang"/></xsl:for-each>
         </xsl:when>
         <xsl:otherwise><xsl:call-template name="getLowerCaseLang"/></xsl:otherwise>
     </xsl:choose>
 </xsl:variable>
 <xsl:attribute name="lang"><xsl:value-of select="$childlang"/></xsl:attribute>
 <xsl:attribute name="xml:lang"><xsl:value-of select="$childlang"/></xsl:attribute>
 <xsl:if test="$childlang='ar-eg' or $childlang='ar' or $childlang='he' or $childlang='he-il'">
  <xsl:attribute name="dir">rtl</xsl:attribute>
 </xsl:if>

<xsl:value-of select="$newline"/>
<head><xsl:value-of select="$newline"/>
  <!-- initial meta information -->
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/><xsl:value-of select="$newline"/>
<!--  <meta http-equiv="generator" content="IBM Darwin Information Typing Architecture dit2htm transform" /><xsl:value-of select="$newline"/> -->

<!-- If there is no copyright in the document, make the standard IBM one -->
<xsl:if test="not(//*[contains(@class,' topic/copyright ')])">
  <meta name="copyright">
   <xsl:attribute name="content">
   <xsl:text>(C) </xsl:text>
   <xsl:call-template name="getString">
    <xsl:with-param name="stringName" select="'Copyright IBM'"/>
   </xsl:call-template>
   <xsl:text> </xsl:text><xsl:value-of select="$YEAR"/>
   </xsl:attribute>
  </meta>
  <xsl:value-of select="$newline"/>
  <meta name="DC.rights.owner">
   <xsl:attribute name="content">
   <xsl:text>(C) </xsl:text>
   <xsl:call-template name="getString">
    <xsl:with-param name="stringName" select="'Copyright IBM'"/>
   </xsl:call-template>
   <xsl:text> </xsl:text><xsl:value-of select="$YEAR"/>
   </xsl:attribute>
  </meta>
  <xsl:value-of select="$newline"/>
</xsl:if>

  <meta name="security" content="public" /><xsl:value-of select="$newline"/>
  <meta name="Robots" content="index,follow" /><xsl:value-of select="$newline"/>
  <xsl:text disable-output-escaping="yes">&lt;meta http-equiv="PICS-Label" content='(PICS-1.1 "http://www.icra.org/ratingsv02.html" l gen true r (cz 1 lz 1 nz 1 oz 1 vz 1) "http://www.rsac.org/ratingsv01.html" l gen true r (n 0 s 0 v 0 l 0) "http://www.classify.org/safesurf/" l gen true r (SS~~000 1))' /></xsl:text>
  <xsl:value-of select="$newline"/>

  <xsl:call-template name="getMeta"/>

  <!-- IBM Copyright text -->
  <xsl:call-template name="ibmcopyright"/>

 <xsl:variable name="urltest"> <!-- test for URL -->
  <xsl:call-template name="url-string">
   <xsl:with-param name="urltext" select="$CSSPATH"/>
  </xsl:call-template>
 </xsl:variable>
<!--<xsl:message>CSSPATH=<xsl:value-of select="$CSSPATH"/></xsl:message>-->
<!--<xsl:message>URLTEST=<xsl:value-of select="$urltest"/></xsl:message>-->

  <!-- IBM DITA style sheet always output - but based on bidi language -->
 <xsl:choose>
  <xsl:when test="($childlang='ar-eg' or $childlang='ar' or $childlang='he' or $childlang='he-il') and ($urltest='url')">
   <link rel="stylesheet" type="text/css" href="{$CSSPATH}{$bidi-ibmdita-css}" />
  </xsl:when>
  <xsl:when test="($childlang='ar-eg' or $childlang='ar' or $childlang='he' or $childlang='he-il') and ($urltest='')">
   <link rel="stylesheet" type="text/css" href="{$PATH2PROJ}{$CSSPATH}{$bidi-ibmdita-css}" />
  </xsl:when>
  <xsl:when test="not($childlang='ar-eg' or $childlang='ar' or $childlang='he' or $childlang='he-il') and ($urltest='url')">
   <link rel="stylesheet" type="text/css" href="{$CSSPATH}{$ibmdita-css}" />
  </xsl:when>
  <xsl:otherwise>
   <link rel="stylesheet" type="text/css" href="{$PATH2PROJ}{$CSSPATH}{$ibmdita-css}" />
  </xsl:otherwise>
 </xsl:choose>
  <xsl:value-of select="$newline"/>
  <!-- Add user's style sheet if requested to -->
  <xsl:if test="string-length($CSS)>0">
   <xsl:choose>
    <xsl:when test="$urltest='url'">
     <link rel="stylesheet" type="text/css" href="{$CSSPATH}{$CSS}" />
    </xsl:when>
    <xsl:otherwise>
     <link rel="stylesheet" type="text/css" href="{$PATH2PROJ}{$CSSPATH}{$CSS}" />
    </xsl:otherwise>
   </xsl:choose><xsl:value-of select="$newline"/>
  </xsl:if>
  <!--  jta added following line 06/14/2006
  <xsl:text disable-output-escaping="yes">&lt;script type="text/javascript" src="../../com.ibm.help.doc/scripts/resizer.js"&gt;</xsl:text>
   -->
  <!-- add javascript for resizing images ****** jta removed 06/14/2006
  <xsl:text disable-output-escaping="yes">&lt;script type="text/javascript"&gt;
  function resizeimage(imageid) {
    var iw, ih, nw, nh, ww, wh, w, h;
    w = imageid.width;
    h = imageid.height;
    if (window.innerWidth == null) {
      iw = document.body.clientWidth;
      ih = document.body.clientHeight;
    } else {
      iw = window.innerWidth;
      ih = window.innerHeight;
    }
    if ((w &gt; iw) || (h &gt; ih)) {
      if (ih/h &gt;= iw/w) {
        nw = iw-25;
        nh=h*(nw/w);
      } else {
        nh=ih-25;
        nw=w*(nh/h);
      }
    } else {
      nw=w;
      nh=h;
    }
    imageid.width=nw;
    imageid.height=nh;
  }
  function reload() {location = location;}
  &lt;/script&gt;</xsl:text><xsl:value-of select="$newline"/>
  -->

  <!-- Title processing - special handling for short descriptions -->
    <title>
      <xsl:call-template name="gen-user-panel-title-pfx"/> <!-- hook for a user-XSL title prefix -->
      <!-- use the searchtitle unless there's no value - else use title -->
      <xsl:variable name="schtitle"><xsl:value-of select="/*[contains(@class,' topic/topic ')]/*[contains(@class,' topic/titlealts ')]/*[contains(@class,' topic/searchtitle ')]"/></xsl:variable>
      <xsl:variable name="ditaschtitle"><xsl:value-of select="/dita/*[contains(@class,' topic/topic ')][1]/*[contains(@class,' topic/titlealts ')]/*[contains(@class,' topic/searchtitle ')]"/></xsl:variable>
      <xsl:variable name="maintitle"><xsl:apply-templates select="/*[contains(@class,' topic/topic ')]/*[contains(@class,' topic/title ')]" mode="text-only"/></xsl:variable>
      <xsl:variable name="ditamaintitle"><xsl:apply-templates select="/dita/*[contains(@class,' topic/topic ')][1]/*[contains(@class,' topic/title ')]" mode="text-only"/></xsl:variable>
      <xsl:choose>
       <xsl:when test="string-length($schtitle)>'0'"><xsl:value-of select="$schtitle"/></xsl:when>
       <xsl:when test="string-length($ditaschtitle)>'0'"><xsl:value-of select="$ditaschtitle"/></xsl:when>
       <xsl:when test="string-length($maintitle)>'0'"><xsl:value-of select="$maintitle"/></xsl:when>
       <xsl:when test="string-length($ditamaintitle)>'0'"><xsl:value-of select="$ditamaintitle"/></xsl:when>
       <xsl:otherwise><xsl:text>***</xsl:text>
       <xsl:call-template name="output-message">
         <xsl:with-param name="msg">Topic contains no title; using "***".</xsl:with-param>
         <xsl:with-param name="msgnum">009</xsl:with-param>
         <xsl:with-param name="msgsev">W</xsl:with-param>
       </xsl:call-template>
       </xsl:otherwise>
      </xsl:choose>
    </title><xsl:value-of select="$newline"/>

    <!--do pull processing for resource ID via xsl:choose-->
    <!-- include user's XSL HEAD processing here -->
    <xsl:call-template name="gen-user-head" />
    <!-- include user's XSL javascripts here -->
    <xsl:call-template name="gen-user-scripts" />
    <!-- include user's XSL style element and content here -->
    <xsl:call-template name="gen-user-styles" />

  <!-- Add user's head XHTML code snippet if requested to -->
  <xsl:if test="string-length($HDF)>0">
   <xsl:apply-templates select="document($HDF)" mode="add-HDF"/>
  </xsl:if>
  </head><xsl:value-of select="$newline"/>

  <body>
  <!-- Already put xml:lang on <html>; do not copy to body-->
  <!--<xsl:call-template name="commonattributes"/>-->
  <xsl:call-template name="setonresize"/> <!-- ****** -->
  <xsl:call-template name="setidaname"/>
  <xsl:value-of select="$newline"/>
  <xsl:call-template name="flagit"/>
  <xsl:call-template name="start-revflag"/>

  <!-- ****** jta removed 06/14/2006
  <xsl:text disable-output-escaping="yes">&lt;script type="text/javascript"&gt;
  if (navigator.appName=="Netscape") {
    setTimeout('window.onresize = reload',500);
  }
  &lt;/script&gt;</xsl:text><xsl:value-of select="$newline"/>
  -->

<!-- Insert previous/next/ancestor breadcrumbs links at the top of the xhtml. -->
  <xsl:apply-templates select="*[contains(@class,' topic/related-links ')]" mode="breadcrumb"/>

  <!-- include user's XSL running header here -->
  <xsl:call-template name="gen-user-header"/>
  <!-- Add user's running heading XHTML code snippet if requested to -->
  <xsl:if test="string-length($HDR)>0">
   <xsl:copy-of select="document($HDR)"/>
  </xsl:if>
  <xsl:value-of select="$newline"/>
  <!-- Include a user's XSL call here to generate a toc based on what's a child of topic -->
  <xsl:call-template name="gen-user-sidetoc"/>

    <xsl:apply-templates/> <!-- this will include all things within topic; therefore, -->
    <!-- title content will appear here by fall-through -->
    <!-- followed by prolog (but no fall-through is permitted for it) -->
    <!-- followed by body content, again by fall-through in document order -->
    <!-- followed by related links -->
    <!-- followed by child topics by fall-through -->

  <!-- include footnote-endnotes -->
  <xsl:call-template name="gen-endnotes"/>

  <!-- include user's XSL running footer here -->
  <xsl:call-template name="gen-user-footer"/>
  <!-- Add user's running footing XHTML code snippet if requested to -->
  <xsl:if test="string-length($FTR)>0">
   <xsl:copy-of select="document($FTR)"/>
  </xsl:if>
  <xsl:value-of select="$newline"/>
 <xsl:call-template name="end-revflag"/>

  </body><xsl:value-of select="$newline"/>
</html>
</xsl:template>

<!-- ****** -->
<xsl:template name="setonresize">
 <!-- jta added below 06/14/2006 -->
 <xsl:attribute name="onload">
   <xsl:value-of select="$jscriptonload"/>
 </xsl:attribute>
 <xsl:attribute name="onresize">
   <!-- jta removed 06/14/2006 <xsl:value-of select="$jscriptreload"/> -->
   <xsl:value-of select="$jscriptresize"/>
 </xsl:attribute>
</xsl:template>


<!--
fixes for Eclipse extensions
-->
  <!-- Locates elements that have an outputclass attribute that contains
  'include' and replaces it with an include element. -->
  <!-- Amended to avoid avoid duplicate rule matches with the topic.p template.
       dwh 21.Aug.2006 -->
  <xsl:template match="//*[not(contains(@class,' topic/p ')) and contains(@outputclass, 'include')]">
    <xsl:element name="include">
      <xsl:attribute name="path"><xsl:value-of select="substring-after(@outputclass, 'include_')" /></xsl:attribute>
    </xsl:element>
    <xsl:apply-templates />
  </xsl:template>


  <!-- Locates elements that have an outputclass attribute that contains
  'anchor' and replaces it with an anchor element. -->
  <!-- Amended to avoid avoid duplicate rule matches with the topic.p template.
       dwh 21.Aug.2006 -->
  <xsl:template match="//*[not(contains(@class,' topic/p ')) and contains(@outputclass, 'anchor_')]">
    <xsl:element name="anchor">
      <xsl:attribute name="id"><xsl:value-of select="substring-after(@outputclass, 'anchor_')" /></xsl:attribute>
    </xsl:element>
    <xsl:apply-templates />
  </xsl:template>


  <!-- Locates outputclass attributes that contain product filters
  and replaces them with filter attributes that point to products. -->
  <xsl:template match="//@outputclass[contains(., 'filter_product')]">
    <xsl:attribute name="filter">product=<xsl:value-of select="substring-after(., 'filter_product_')" /></xsl:attribute>
    <xsl:apply-templates />
  </xsl:template>

  <!-- Locates outputclass attributes that contain os filters
  and replaces them with filter attributes that point to the
  appropriate operating system. -->
  <xsl:template match="//@outputclass[contains(., 'filter_os')]">
    <xsl:choose>
      <xsl:when test="contains(., '_not_')">
        <xsl:attribute name="filter">os!=<xsl:value-of select="substring-after(., 'filter_os_not_')" /></xsl:attribute>
      </xsl:when>
      <xsl:otherwise>
        <xsl:attribute name="filter">os=<xsl:value-of select="substring-after(., 'filter_os_')" /></xsl:attribute>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates />
  </xsl:template>

  <!-- Locates outputclass attributes that contain plugin filters
  and replaces them with filter attributes that point to the presence of
  the corresponding plug-in. -->
  <xsl:template match="//@outputclass[contains(., 'filter_plugin')]">
    <xsl:choose>
      <xsl:when test="contains(., '_not_')">
        <xsl:attribute name="filter">plugin!=<xsl:value-of select="substring-after(., 'filter_plugin_not_')" /></xsl:attribute>
      </xsl:when>
      <xsl:otherwise>
        <xsl:attribute name="filter">plugin=<xsl:value-of select="substring-after(., 'filter_plugin_')" /></xsl:attribute>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates />
  </xsl:template>

  <!-- Replaces outputclass attributes that contain ids
  and replaces them with id attributes. -->
  <xsl:template match="//@outputclass[contains(., 'id_')]">
    <xsl:attribute name="id"><xsl:value-of select="substring-after(., 'id_')" /></xsl:attribute>
    <xsl:apply-templates />
  </xsl:template>
<!--
end of fixes for Eclipse extensions
-->

<!-- override for Get Ready twisty, added 07/21/2006 jta    -->
<!-- these are based on IDWB 3.8.6 templates                -->
<!-- additions or changes noted by ******                   -->

<xsl:template match="*[contains(@class,' task/prereq ')]" name="topic.task.prereq">
<div class="p">
  <xsl:call-template name="commonattributes"/>
  <xsl:call-template name="gen-toc-id"/>
  <xsl:call-template name="setidaname"/>
 <xsl:variable name="revtest">
   <xsl:if test="@rev and not($FILTERFILE='') and ($DRAFT='yes')"> <!-- revision? -->
   <xsl:call-template name="find-active-rev-flag">               <!-- active? (revtest will be 1 when active)-->
     <xsl:with-param name="allrevs" select="@rev"/>
   </xsl:call-template>
   </xsl:if>
 </xsl:variable>
 <xsl:choose>
   <xsl:when test="$revtest=1">   <!-- Rev is active - add the DIV -->
  <div class="{@rev}">
     <xsl:choose>
        <xsl:when test="descendant::*[contains(@outputclass,'getready')]">
          <div class="getready">
            <div class="collapseheadgetready">
              <xsl:apply-templates select="*[contains(@class,' topic/p ')][@outputclass='getready']"/>
            </div>
            <div class="collapsecontent">
                <div class="section">
                  <xsl:apply-templates select="*[contains(@class,' topic/ul ')][@outputclass='getready']"/>
                </div>
            </div>
          </div>
          <xsl:apply-templates select="*[not(contains(@outputclass,'getready'))]"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates select="."   mode="prereq-fmt" />
        </xsl:otherwise>
     </xsl:choose>
  </div>
   </xsl:when>
   <xsl:otherwise>  <!-- Rev wasn't active - process normally -->
     <xsl:choose>
        <xsl:when test="descendant::*[contains(@outputclass,'getready')]">
          <div class="getready">
            <div class="collapseheadgetready">
              <xsl:apply-templates select="*[contains(@class,' topic/p ')][@outputclass='getready']"/>
            </div>
             <div class="collapsecontent">
                <div class="section">
                <xsl:apply-templates select="*[contains(@class,' topic/ul ')][@outputclass='getready']"/>
             </div>
              </div>
            </div>
            <xsl:apply-templates select="*[not(contains(@outputclass,'getready'))]"/>
           </xsl:when>
           <xsl:otherwise>
             <xsl:apply-templates select="." mode="prereq-fmt" />
           </xsl:otherwise>
       </xsl:choose>
   </xsl:otherwise>
 </xsl:choose>
</div><xsl:value-of select="$newline"/>
</xsl:template>



<xsl:template match="*[contains(@class,' topic/p ')]" name="topic.p">
 <!-- To ensure XHTML validity, need to determine whether the DITA kids are block elements.
      If so, use div_class="p" instead of p -->
 <xsl:choose>
  <xsl:when test="descendant::*[contains(@class,' topic/pre ')] or
       descendant::*[contains(@class,' topic/screen ')] or
       descendant::*[contains(@class,' topic/ul ')] or
       descendant::*[contains(@class,' topic/sl ')] or
       descendant::*[contains(@class,' topic/ol ')] or
       descendant::*[contains(@class,' topic/lq ')] or
       descendant::*[contains(@class,' topic/dl ')] or
       descendant::*[contains(@class,' topic/note ')] or
       descendant::*[contains(@class,' topic/lines ')] or
       descendant::*[contains(@class,' topic/fig ')] or
       descendant::*[contains(@class,' topic/table ')] or
       descendant::*[contains(@class,' topic/simpletable ')]">
       <xsl:choose>
        <xsl:when test="@outputclass[contains(., 'getready')]">  <!-- ****** -->
            <a href="javascript:void(0)" class="collapsehead" onclick="collapse(this)">
              <xsl:value-of select="." />
            </a>
        </xsl:when>  <!-- ****** -->
       <xsl:otherwise>
           <div class="p"><xsl:call-template name="commonattributes"/><xsl:call-template name="setidaname"/><xsl:call-template name="flagit"/><xsl:call-template name="revblock"/></div>
       </xsl:otherwise> <!-- ****** -->
     </xsl:choose> <!-- ****** -->
     <!-- Added here to avoid dupulicate rule matching for p elements.
          dwh 18.Aug.2006-->
     </xsl:when>
       <xsl:when test="@outputclass[contains(., 'include')]">
         <xsl:element name="include">
           <xsl:attribute name="path"><xsl:value-of select="substring-after(@outputclass, 'include_')" /></xsl:attribute>
         </xsl:element>
       </xsl:when>
       <xsl:when test="@outputclass[contains(., 'anchor_')]">
         <xsl:element name="anchor">
           <xsl:attribute name="id"><xsl:value-of select="substring-after(@outputclass, 'anchor_')" /></xsl:attribute>
         </xsl:element>
      </xsl:when>
      <xsl:otherwise>
    <xsl:choose>  <!-- ****** -->
        <xsl:when test="@outputclass[contains(., 'getready')]">  <!-- ****** -->
            <a href="javascript:void(0)" class="collapsehead" onclick="collapse(this)">
              <xsl:value-of select="." />
            </a>
        </xsl:when>  <!-- ****** -->
       <xsl:otherwise>  <!-- ****** -->
           <p><xsl:call-template name="commonattributes"/><xsl:call-template name="setidaname"/><xsl:call-template name="flagit"/><xsl:call-template name="revblock"/></p>
       </xsl:otherwise>  <!-- ****** -->
     </xsl:choose>  <!-- ****** -->
   </xsl:otherwise>
 </xsl:choose><xsl:value-of select="$newline"/>
</xsl:template>

  <!-- Creates a link to Web feeds specified by writers in note elements
  that have outputclass attibutes with the value 'webfeed'.
  dwh :: 17.May.2007 -->
  <xsl:template match="*[contains(@class,' topic/note ')][@outputclass='webfeed']" name="topic.note.webfeed">
      <xsl:call-template name="spec-title"/>
      <xsl:value-of select="$newline"/>
      <div class="webfeed">
        <span class="notetitle">
          <xsl:element name="a">
            <xsl:attribute name="class">webfeed-link</xsl:attribute>
            <xsl:attribute name="title">Shows English articles</xsl:attribute>
            <xsl:attribute name="href">javascript:void(0)</xsl:attribute>
            <xsl:attribute name="onClick">getWebFeed('<xsl:value-of select="xref/@href" />',this);</xsl:attribute>
            <xsl:value-of select="xref" />
          </xsl:element>
        </span>
       </div>
  </xsl:template>

</xsl:stylesheet>